@@ -1,6 +1,4 @@
-import logging
-import re
-from functools import lru_cache
+import json
 from os import getenv
 from typing import Any, Dict, Literal, Optional
 from urllib.parse import urljoin
@@ -10,50 +8,17 @@ from requests.exceptions import RequestException
 from voluptuous import Invalid, MultipleInvalid
 from voluptuous.humanize import humanize_error
 
-from .env import (
-    DVC_STUDIO_CLIENT_LOGLEVEL,
-    DVC_STUDIO_OFFLINE,
-    DVC_STUDIO_REPO_URL,
-    DVC_STUDIO_TOKEN,
-    DVC_STUDIO_URL,
-    STUDIO_ENDPOINT,
-    STUDIO_REPO_URL,
-    STUDIO_TOKEN,
-)
+from . import logger
+from .config import get_studio_config
+from .env import DVC_STUDIO_TOKEN, STUDIO_ENDPOINT, STUDIO_TOKEN
 from .schema import SCHEMAS_BY_TYPE
 
-STUDIO_URL = "https://studio.iterative.ai"
-
-logger = logging.getLogger(__name__)
-logger.setLevel(getenv(DVC_STUDIO_CLIENT_LOGLEVEL, "INFO").upper())
-
-
-def _get_remote_url() -> str:
-    from dulwich.porcelain import get_remote_repo
-    from dulwich.repo import Repo
-
-    with Repo.discover() as repo:
-        try:
-            _remote, url = get_remote_repo(repo)
-        except IndexError:
-            # IndexError happens when the head is detached
-            _remote, url = get_remote_repo(repo, b"origin")
-        return url
-
-
-@lru_cache(maxsize=1)
-def get_studio_repo_url() -> Optional[str]:
-    from dulwich.errors import NotGitRepository
-
-    try:
-        return _get_remote_url()
-    except NotGitRepository:
-        logger.warning(
-            "Couldn't find a valid Studio Repo URL.\n"
-            "You can try manually setting the environment variable `%s`.",
-            STUDIO_REPO_URL,
-        )
-        return None
+# Studio PROD and DEV have a hardcoded limit of 30MB for the request body.
+MAX_REQUEST_SIZE = 29000000
+# Studio backend discards files larger than 10MB as big files when parsing commits.
+MAX_PLOT_SIZE = 10000000
+# Studio backend limit number of files inside a plot directory.
+MAX_NUMBER_OF_PLOTS = 200
 
 
 def get_studio_token_and_repo_url(studio_token=None, studio_repo_url=None):
@@ -65,92 +30,80 @@ def get_studio_token_and_repo_url(studio_token=None, studio_repo_url=None):
     return config.get("token"), config.get("repo_url")
 
 
-def get_studio_config(
-    dvc_studio_config: Optional[Dict[str, Any]] = None,
-    offline: bool = False,
-    studio_token: Optional[str] = None,
-    studio_repo_url: Optional[str] = None,
-    studio_url: Optional[str] = None,
-) -> Dict[str, Any]:
-    """Get studio config options.
+def _single_post(url, body, token):
+    try:
+        response = requests.post(
+            url,
+            json=body,
+            headers={
+                "Content-type": "application/json",
+                "Authorization": f"token {token}",
+            },
+            timeout=(30, 5),
+        )
+    except RequestException as e:
+        logger.warning(f"Failed to post to Studio: {e}")
+        return False
 
-    Args:
-        dvc_studio_config (Optional[dict]): Dict returned by dvc.Repo.config["studio"].
-        offline (bool): Whether offline mode is enabled. Default: false.
-        studio_token (Optional[str]): Studio access token obtained from the UI.
-        studio_repo_url (Optional[str]): URL of the Git repository that has been
-            imported into Studio UI.
-        studio_url (Optional[str]): Base URL of Studio UI (if self-hosted).
-    Returns:
-        Dict:
-            Config options for posting live metrics.
-            Keys match the DVC studio config section.
-            Example:
-                {
-                    "token": "mytoken",
-                    "repo_url": "git@github.com:iterative/dvc-studio-client.git",
-                    "url": "https://studio.iterative.ai",
-                }
-    """
+    message = response.content.decode()
+    logger.debug(
+        f"post_to_studio: {response.status_code=}" f", {message=}" if message else ""
+    )
 
-    config = {}
-    if not dvc_studio_config:
-        dvc_studio_config = {}
+    if response.status_code != 200:
+        logger.warning(f"Failed to post to Studio: {message}")
+        return False
 
-    def to_bool(var):
-        if var is None:
+    return True
+
+
+def _post_in_chunks(url, body, token):
+    plots = body.pop("plots")
+
+    # First, post only metrics and params
+    if not _single_post(url, body, token):
+        return False
+    body.pop("metrics", None)
+    body.pop("params", None)
+
+    # Studio backend has a limitation on the size of the request body.
+    # So we try to send as many plots as possible without xeceeding the limit.
+    body["plots"] = {}
+    total_size = 0
+    for n, (plot_name, plot_data) in enumerate(plots.items()):
+        if n >= MAX_NUMBER_OF_PLOTS:
+            logger.warning(
+                f"Number of plots exceeds Studio limit ({MAX_NUMBER_OF_PLOTS}). "
+                "Some plots will not be sent."
+            )
+            break
+
+        if "data" in plot_data:
+            size = len(json.dumps(plot_data["data"]).encode("utf-8"))
+        elif "image" in plot_data:
+            size = len(plot_data["image"])
+
+        if size > MAX_PLOT_SIZE:
+            logger.warning(
+                f"Size of plot exceeds Studio limit ({MAX_PLOT_SIZE}). "
+                f"{plot_name} will not be sent."
+            )
+            continue
+
+        total_size += size
+        if total_size > MAX_REQUEST_SIZE:
+            logger.warning(
+                f"Total size of plots exceeds Studio limit ({MAX_REQUEST_SIZE}). "
+                "Some plots will not be sent."
+            )
+            break
+        body["plots"][plot_name] = plot_data
+
+    if body["plots"]:
+        if not _single_post(url, body, token):
             return False
-        return bool(re.search("1|y|yes|true", str(var), flags=re.I))
 
-    offline = (
-        offline
-        or to_bool(getenv(DVC_STUDIO_OFFLINE))
-        or to_bool(dvc_studio_config.get("offline"))
-    )
-    if offline:
-        logger.debug("Offline mode enabled. Skipping `post_studio_live_metrics`")
-        return {}
-
-    studio_token = (
-        studio_token
-        or getenv(DVC_STUDIO_TOKEN)
-        or getenv(STUDIO_TOKEN)
-        or dvc_studio_config.get("token")
-    )
-    if not studio_token:
-        logger.debug(
-            f"{DVC_STUDIO_TOKEN} not found. Skipping `post_studio_live_metrics`"
-        )
-        return {}
-    config["token"] = studio_token
-
-    studio_repo_url = (
-        studio_repo_url
-        or getenv(DVC_STUDIO_REPO_URL)
-        or getenv(STUDIO_REPO_URL)
-        or dvc_studio_config.get("repo_url")
-    )
-    if studio_repo_url is None:
-        logger.debug(
-            f"{DVC_STUDIO_REPO_URL} not found. Trying to automatically find it."
-        )
-        studio_repo_url = get_studio_repo_url()
-    if studio_repo_url:
-        config["repo_url"] = studio_repo_url
-    else:
-        logger.debug(
-            f"{DVC_STUDIO_REPO_URL} not found. Skipping `post_studio_live_metrics`"
-        )
-        return {}
-
-    studio_url = studio_url or getenv(DVC_STUDIO_URL) or dvc_studio_config.get("url")
-    if studio_url:
-        config["url"] = studio_url
-    else:
-        logger.debug(f"{DVC_STUDIO_URL} not found. Using {STUDIO_URL}.")
-        config["url"] = STUDIO_URL
-
-    return config
+    return True
 
 
 def post_live_metrics(  # noqa: C901
@@ -229,6 +182,9 @@ def post_live_metrics(  # noqa: C901
             plots={
                 "dvclive/plots/metrics/foo.tsv": {
                     "data": [{"step": 0, "foo": 1.0}]
+                },
+                "dvclive/plots/images/bar.png": {
+                    "image": "base64-string"
                 }
             }
             ```
@@ -287,7 +243,6 @@ def post_live_metrics(  # noqa: C901
         body["step"] = step
         if plots:
             body["plots"] = plots
-
     elif event_type == "done":
         if experiment_rev:
             body["experiment_rev"] = experiment_rev
@@ -303,26 +258,12 @@ def post_live_metrics(  # noqa: C901
         return None
 
     logger.debug(f"post_studio_live_metrics `{event_type=}`")
-    logger.debug(f"JSON body `{body=}`")
 
     path = getenv(STUDIO_ENDPOINT) or "api/live"
     url = urljoin(config["url"], path)
-    try:
-        response = requests.post(
-            url,
-            json=body,
-            headers={
-                "Content-type": "application/json",
-                "Authorization": f"token {config['token']}",
-            },
-            timeout=(30, 5),
-        )
-    except RequestException:
-        return False
+    token = config["token"]
 
-    message = response.content.decode()
-    logger.debug(
-        f"post_to_studio: {response.status_code=}" f", {message=}" if message else ""
-    )
+    if body["type"] != "data" or "plots" not in body:
+        return _single_post(url, body, token)
 
-    return response.status_code == 200
+    return _post_in_chunks(url, body, token)
